'\"
'\" Copyright (c) 1993  Software Research Associates, Inc.
'\" Permission to use, copy, modify, and distribute this software and its
'\" documentation for any purpose and without fee is hereby granted, provided
'\" that the above copyright notice appear in all copies and that both that
'\" copyright notice and this permission notice appear in supporting
'\" documentation, and that the name of Software Research Associates not be
'\" used in advertising or publicity pertaining to distribution of the
'\" software without specific, written prior permission.  Software Research
'\" Associates makes no representations about the suitability of this software
'\" for any purpose.  It is provided "as is" without express or implied
'\" warranty.
'\" 
'\" $Id: TclJP.man,v 1.1 1993/11/15 06:54:41 nisinaka Exp $
'
.so man.macros
.de UL
\\$1\l'|0\(ul'\\$2
..
.HS TclJP tcl
.if n .na
.BS
.SH NAME
TclJapanization \- overview of Tcl Japanization
.BE

.SH INTRODUCTION
This document provides an overview of the Japanization of Tcl.
The Japanization includes the following features:
.RS
.nf

* Parse scripts that contain kanji strings.
* New commands for handling kanji strings.

.fi
.RE
There are two main policies for the Japanization:
"Users do not have to worry about details like kanji code"
and
"Any scripts for the original Tcl are executable".
'
.SH "KANJI CODE"
You can include kanji strings in Tcl scripts.
Our Japanization supports three kinds of kanji code:
\fBJIS\fP, \fBEUC\fP, and \fBShift-JIS\fP.
We do not support the kana character set encoded with one byte
(which is, so called, HANKAKU-KANA).
.PP
When the Tcl interpreter parses a script,
it automatically examines the kanji code.
This means that the user does not have to specify the kanji code beforehand
and can write kanji strings without worrying about their kanji code.
Even though the current implementation allows you to use
different kanji codes in a same script file, 
we do not recommend mixing different kanji codes.
.PP
The Japanized Tcl maintains a set of codes
that indicate the type of kanji characters
being handled by the Tcl interpreter (the internal code)
and for file I/O (the file input and output codes).
Regardless of the source of input (script or file I/O),
the Tcl interpreter converts strings to the particular kanji code
specified by the user.
.TP 4
Internal code
Any kanji will be automatically converted into the specifed
kanji code when the Tcl interpreter parses scripts.
Regardless of the original kanji code,
the Tcl interpreter converts kanji strings to this kanji code.
This code is called "internal code".
There are three kinds of kanji code:
\fBJIS\fP, \fBEUC\fP, and \fBShift-JIS\fP.
The internal code is specified by the environment variable
.B LANG
when you execute an application based on Tcl.
You can change the internal code
by \fBkanji internalCode\fP command (which is described later).
.br
If you change the internal code after the first kanji character is recognized,
you may encounter errors.
So we suggest taking care when chaging the internal code.
.br
Since the Tcl interpreter encodes kanji strings with the internal code,
the results of Tcl commands are also encoded with the internal code.
.TP 4
File input code
When you use the \fBgets\fP command to read strings,
you can convert this kanji code.
Again, regardless of the original kanji code,
the code will be converted to the specified one.
You can specify a file input code for each file
using the \fBkanji inputCode\fP command.
File input codes are: \fBJIS\fP, \fBEUC\fP, \fBShift-JIS\fP, or \fBANY\fP.
\fBANY\fP means that kanji strings are recognized as kanji
but their kanji code will not be changed.
The default of a file input code is \fBANY\fP.
.TP 4
File output code
When you use \fBputs\fP command to write strings,
you can convert their kanji code.
You can specify a file output code for each file
using the \fBkanji outputCode\fP command.
File output codes are: \fBJIS\fP, \fBEUC\fP, \fBShift-JIS\fP, or \fBANY\fP.
The default of a file output code is \fBANY\fP.
'
.SH "COMMANDS FOR HANDLING KANJI STRINGS"
The
.B kanji
command handles kanji strings and their kanji code.
.TP 4
\fBkanji\fP \fIoption\fP ?\fIarg ...\fP?
Perform one of several kanji operations for kanji strings,
depending on \fIoption\fR.
.RS
.TP 4
\fBkanji code \fIstring\fR
Returns the type of kanji code used to encode \fIstring\fR.
Return value will be either \fBJIS\fP, \fBSJIS\fP,
\fBEUC\fP, or \fBANY\fP.
\fBANY\fP means the \fIstring\fR does not include any kanji strings.
.TP 4
\fBkanji conversion \fIfrom-code\fR \fIto-code\fR \fIstring\fR
Does the kanji code conversion of \fIstring\fR and returns the
converted string.
\fIFrom-code\fR specifies the kanji code of \fIstring\fR, and
\fIto-code\fR specifies the kanji code to be converted.
The valid kanji codes for \fIfrom-code\fR and \fIto-code\fR are
\fBJIS\fP, \fBSJIS\fP and \fBEUC\fP.
.TP 4
\fBkanji defaultInputCode\fR ?\fIkanji-code\fR?
Returns the default kanji code for input with the \fBgets\fP command.
If \fIkanji-code\fR is specified,
then change the default file input code.
The return value or the value you can specify will be one of:
\fBJIS\fP, \fBSJIS\fP, \fBEUC\fP, and \fBANY\fP.
\fBANY\fP means that kanji strings are recognized as kanji
but their kanji code will not be converted.
The initial value is always \fBANY\fP.
.TP 4 
\fBkanji defaultOutputCode\fR ?\fIkanji-code\fR?
Returns the default kanji code for output with the \fBputs\fP command.
If \fIkanji-code\fR is specified,
then change the default file output code.
The return value or the value you can specify will be one of:
\fBJIS\fP, \fBSJIS\fP, \fBEUC\fP, and \fBANY\fP.
The initial value is always \fBANY\fP.
.TP 4
\fBkanji inputCode \fIfileId\fR ?\fIkanji-code\fR?
Returns the file input code of the file \fIfileId\fR.
If \fIkanji-code\fR is specified,
then change the file input code to \fIkanji-code\fR.
.TP 4
\fBkanji internalCode\fR ?\fIkanji-code\fR?
Returns the current internal code.
If \fIkanji-code\fR is specified,
then change the internal code to \fIkanji-code\fR.
The return value or the value you can specify will be one of:
\fBJIS\fP, \fBSJIS\fP, and \fBEUC\fP.
The initinal value of the internal code is defined by
the environment variable \fBLANG\fP.
.TP 4
\fBkanji lsearch \fIlist\fR \fIpattern\fR
.TP 4
\fBklsearch \fIlist\fR \fIpattern\fR
These two are the \fBlsearch\fP command for kanji strings.
It takes the same arguments as the Tcl \fBlsearch\fP command.
.TP 4
\fBkanji lsort \fIlist\fR
.TP 4
\fBklsort \fIlist\fR
These two are the \fBlsort\fP command for kanji strings.
It takes the same arguments as the Tcl \fBlsort\fP command.
.TP 4
\fBkanji outputCode \fIfileId\fP ?\fIkanji-code\fR?
Returns the file output code of the file \fIfileId\fR.
If \fIkanji-code\fR is specified,
then change the file output code to \fIkanji-code\fR.
.TP 4
\fBkanji string \fIoption\fR \fIarg\fR ?\fIarg ...\fR?
.TP 4
\fBkstring \fIoption\fR \fIarg\fR ?\fIarg ...\fR?
These two are the \fBstring\fP command for kanji string.
It takes the same arguments as the Tcl \fBstring\fP command.
.RE
.PP
The \fBfile\fP command is also extended
to know what kanji code is used in the file.
.TP 4
\fBfile kanjiCode\fR \fIfilename\fR
Returns the kanji code of the file.
The \fIfilename\fR gives the name of the file
you want to know its kanji code.
If the file does not include any kanji strings,
this command returns \fBANY\fP.
'
.SH "COEXISTING WITH THE ORIGINAL TCL"
No library file (usually installed in "/usr/local/lib/tcl")
is modified for the Japanization.
Libraries and scripts written for the original Tcl can be used
with this Japanized Tcl.
'
.SH PROBLEMS
\fBregexp/regsub\fP are not Japanized, yet.
.PP
The support for JIS code is not complete.
We recommend using EUC or Shift-JIS.
'
.SH AUTHORS
The original Tcl/Tk was developped by
Dr. John Ousterhout (ouster@sprite.berkeley.edu)
from University of California at Berkeley.
This Japanization is mainly done by Yoshiyuki Nishinaka (nisinaka@sra.co.jp)
from Software Research Associates, Inc. with the supports of
Hiroshi Sako (sakoh@sra.co.jp) and Makoto Ishisone (ishisone@sra.co.jp).
